Previous Section - Pizza.py WWW Site - Pizza.py Documentation - Pizza.py Tools - Next Section

### 4. Tools within Pizza.py

Th previous section describes how Pizza.py tools are used in Pizza.py.

Help on the syntax for invoking a tool and using its methods and settings can be accessed interactively within Pizza.py itself by typing "? tool" or "?? tool". Typing "??" gives a one-line description of each tool.

These are the different categories of Pizza.py tools:

LAMMPS in/out files | chain, data, dump, log, patch, bdump, ldump, tdump
ChemCell in/out files | cdata, clog, dump
Visualization | gl, rasmol, raster, svg, vmd
File conversion | cfg, ensight, pdbfile, vtk, xyz
GUI wrappers | animate, image, plotview, vcr
Plotting | gnu, matlab
Miscellaneous | histo, mdump, pair, vec

Within the plotting and viz categories, individual tools share many common methods, so the tools can often be used interchangeably. For example, the same script can produce an animation using either Raster3d or SVG to generate the movie frames, by simply changing the line that creates the visualizer object, or by passing the object into the script as an argument.

This is the complete list of tools in Pizza.py; the link is to each tool's documentation page.

animate.py | Animate a series of image files
bdump.py | Read LAMMPS dump local files with bond info
cdata.py | Read, write, manipulate Chemcell data files
chain.py | Create bead-spring chains for LAMMPS input
cfg.py | Convert LAMMPS snapshots to CFG format
clog.py | Read ChemCell log files and extract species data
data.py | Read, write, manipulate LAMMPS data files
dump.py | Read, write, manipulate dump files and particle attributes
ensight.py | Convert LAMMPS snapshots to Ensight format
gl.py | 3d interactive visualization via OpenGL
gnu.py | Create plots via GnuPlot plotting program
histo.py | Particle density histogram from a dump
image.py | View and manipulate images
ldump.py | Read LAMMPS dump files with line info
log.py | Read LAMMPS log files and extract thermodynamic data
matlab.py | Create plots via MatLab numerical analysis program
mdump.py | Read, write, manipulate mesh dump files
pair.py | Compute LAMMPS pairwise energies
patch.py | Create patchy Lennard-Jones particles for LAMMPS input
pdbfile.py | Read, write PDB files in combo with LAMMPS snapshots
plotview.py | Plot multiple vectors from a data set
rasmol.py | 3d visualization via RasMol program
raster.py | 3d visualization via Raster3d program
svg.py | 3d visualization via SVG files
tdump.py | Read LAMMPS dump files with triangle info
vcr.py | VCR-style GUI for 3d interactive OpenGL visualization
vec.py | Create numeric vectors from columns in file or list of vecs
vtk.py | Convert LAMMPS snapshots to VTK format
vmd.py | Wrapper on VMD visualization package
xyz.py | Convert LAMMPS snapshots to XYZ format

This diagram represents the different ways tools can be interconnected by Pizza.py. Tools within the same red box are tools that are (roughly) interchangeable.